@@ -56,10 +56,10 @@ class Executor(object):
             if expression_string is not None:
                 result, convert_exp = self.calc_expression(expression_string)
                 if result:
-                    self.pass_count += self.pass_count
+                    self.pass_count += 1
                     self.log_dump.log("Pass   {}   {} => {}\n".format(expression_info, expression_string, convert_exp))
                 else:
-                    self.fail_count += self.fail_count
+                    self.fail_count += 1
                     self.log_dump.log("Fail   {}   {} => {}\n".format(expression_info, expression_string, convert_exp))
 
     def calc_expression(self, expression):
